@@ -1,7 +1,7 @@
 """
 Type annotations for robomaker service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/literals/)
 
 Usage::
 
@@ -57,6 +57,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -233,6 +234,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -319,6 +321,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -420,6 +423,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -529,3 +533,12 @@ PaginatorName = Literal[
     "list_world_templates",
     "list_worlds",
 ]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-southeast-1",
+    "eu-central-1",
+    "eu-west-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
