@@ -1,7 +1,7 @@
 """
 Type annotations for robomaker service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_robomaker/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_robomaker/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     ArchitectureType,
     ComputeTypeType,
@@ -127,28 +129,39 @@ __all__ = (
     "GetWorldTemplateBodyRequestRequestTypeDef",
     "GetWorldTemplateBodyResponseTypeDef",
     "LaunchConfigTypeDef",
+    "ListDeploymentJobsRequestListDeploymentJobsPaginateTypeDef",
     "ListDeploymentJobsRequestRequestTypeDef",
     "ListDeploymentJobsResponseTypeDef",
+    "ListFleetsRequestListFleetsPaginateTypeDef",
     "ListFleetsRequestRequestTypeDef",
     "ListFleetsResponseTypeDef",
+    "ListRobotApplicationsRequestListRobotApplicationsPaginateTypeDef",
     "ListRobotApplicationsRequestRequestTypeDef",
     "ListRobotApplicationsResponseTypeDef",
+    "ListRobotsRequestListRobotsPaginateTypeDef",
     "ListRobotsRequestRequestTypeDef",
     "ListRobotsResponseTypeDef",
+    "ListSimulationApplicationsRequestListSimulationApplicationsPaginateTypeDef",
     "ListSimulationApplicationsRequestRequestTypeDef",
     "ListSimulationApplicationsResponseTypeDef",
+    "ListSimulationJobBatchesRequestListSimulationJobBatchesPaginateTypeDef",
     "ListSimulationJobBatchesRequestRequestTypeDef",
     "ListSimulationJobBatchesResponseTypeDef",
+    "ListSimulationJobsRequestListSimulationJobsPaginateTypeDef",
     "ListSimulationJobsRequestRequestTypeDef",
     "ListSimulationJobsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListWorldExportJobsRequestListWorldExportJobsPaginateTypeDef",
     "ListWorldExportJobsRequestRequestTypeDef",
     "ListWorldExportJobsResponseTypeDef",
+    "ListWorldGenerationJobsRequestListWorldGenerationJobsPaginateTypeDef",
     "ListWorldGenerationJobsRequestRequestTypeDef",
     "ListWorldGenerationJobsResponseTypeDef",
+    "ListWorldTemplatesRequestListWorldTemplatesPaginateTypeDef",
     "ListWorldTemplatesRequestRequestTypeDef",
     "ListWorldTemplatesResponseTypeDef",
+    "ListWorldsRequestListWorldsPaginateTypeDef",
     "ListWorldsRequestRequestTypeDef",
     "ListWorldsResponseTypeDef",
     "LoggingConfigTypeDef",
@@ -1303,6 +1316,15 @@ LaunchConfigTypeDef = TypedDict(
     total=False,
 )
 
+ListDeploymentJobsRequestListDeploymentJobsPaginateTypeDef = TypedDict(
+    "ListDeploymentJobsRequestListDeploymentJobsPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListDeploymentJobsRequestRequestTypeDef = TypedDict(
     "ListDeploymentJobsRequestRequestTypeDef",
     {
@@ -1322,6 +1344,15 @@ ListDeploymentJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListFleetsRequestListFleetsPaginateTypeDef = TypedDict(
+    "ListFleetsRequestListFleetsPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListFleetsRequestRequestTypeDef = TypedDict(
     "ListFleetsRequestRequestTypeDef",
     {
@@ -1341,6 +1372,16 @@ ListFleetsResponseTypeDef = TypedDict(
     },
 )
 
+ListRobotApplicationsRequestListRobotApplicationsPaginateTypeDef = TypedDict(
+    "ListRobotApplicationsRequestListRobotApplicationsPaginateTypeDef",
+    {
+        "versionQualifier": str,
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListRobotApplicationsRequestRequestTypeDef = TypedDict(
     "ListRobotApplicationsRequestRequestTypeDef",
     {
@@ -1361,6 +1402,15 @@ ListRobotApplicationsResponseTypeDef = TypedDict(
     },
 )
 
+ListRobotsRequestListRobotsPaginateTypeDef = TypedDict(
+    "ListRobotsRequestListRobotsPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListRobotsRequestRequestTypeDef = TypedDict(
     "ListRobotsRequestRequestTypeDef",
     {
@@ -1380,6 +1430,16 @@ ListRobotsResponseTypeDef = TypedDict(
     },
 )
 
+ListSimulationApplicationsRequestListSimulationApplicationsPaginateTypeDef = TypedDict(
+    "ListSimulationApplicationsRequestListSimulationApplicationsPaginateTypeDef",
+    {
+        "versionQualifier": str,
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListSimulationApplicationsRequestRequestTypeDef = TypedDict(
     "ListSimulationApplicationsRequestRequestTypeDef",
     {
@@ -1400,6 +1460,15 @@ ListSimulationApplicationsResponseTypeDef = TypedDict(
     },
 )
 
+ListSimulationJobBatchesRequestListSimulationJobBatchesPaginateTypeDef = TypedDict(
+    "ListSimulationJobBatchesRequestListSimulationJobBatchesPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListSimulationJobBatchesRequestRequestTypeDef = TypedDict(
     "ListSimulationJobBatchesRequestRequestTypeDef",
     {
@@ -1419,6 +1488,15 @@ ListSimulationJobBatchesResponseTypeDef = TypedDict(
     },
 )
 
+ListSimulationJobsRequestListSimulationJobsPaginateTypeDef = TypedDict(
+    "ListSimulationJobsRequestListSimulationJobsPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListSimulationJobsRequestRequestTypeDef = TypedDict(
     "ListSimulationJobsRequestRequestTypeDef",
     {
@@ -1453,6 +1531,15 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+ListWorldExportJobsRequestListWorldExportJobsPaginateTypeDef = TypedDict(
+    "ListWorldExportJobsRequestListWorldExportJobsPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListWorldExportJobsRequestRequestTypeDef = TypedDict(
     "ListWorldExportJobsRequestRequestTypeDef",
     {
@@ -1472,6 +1559,15 @@ ListWorldExportJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListWorldGenerationJobsRequestListWorldGenerationJobsPaginateTypeDef = TypedDict(
+    "ListWorldGenerationJobsRequestListWorldGenerationJobsPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListWorldGenerationJobsRequestRequestTypeDef = TypedDict(
     "ListWorldGenerationJobsRequestRequestTypeDef",
     {
@@ -1491,6 +1587,14 @@ ListWorldGenerationJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListWorldTemplatesRequestListWorldTemplatesPaginateTypeDef = TypedDict(
+    "ListWorldTemplatesRequestListWorldTemplatesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListWorldTemplatesRequestRequestTypeDef = TypedDict(
     "ListWorldTemplatesRequestRequestTypeDef",
     {
@@ -1509,6 +1613,15 @@ ListWorldTemplatesResponseTypeDef = TypedDict(
     },
 )
 
+ListWorldsRequestListWorldsPaginateTypeDef = TypedDict(
+    "ListWorldsRequestListWorldsPaginateTypeDef",
+    {
+        "filters": Sequence["FilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListWorldsRequestRequestTypeDef = TypedDict(
     "ListWorldsRequestRequestTypeDef",
     {
